==================
Dask-Elasticsearch
==================

.. image:: https://img.shields.io/pypi/v/dask-elasticsearch.svg
        :target: https://pypi.python.org/pypi/dask-elasticsearch

.. image:: https://img.shields.io/pypi/pyversions/dask-elasticsearch.svg
        :target: https://pypi.python.org/pypi/dask-elasticsearch

.. image:: https://readthedocs.org/projects/dask-elasticsearch/badge/?version=latest
        :target: https://readthedocs.org/projects/dask-elasticsearch/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/travis/rolando/dask-elasticsearch.svg
        :target: https://travis-ci.org/rolando/dask-elasticsearch

.. image:: https://codecov.io/github/rolando/dask-elasticsearch/coverage.svg?branch=master
    :alt: Coverage Status
    :target: https://codecov.io/github/rolando/dask-elasticsearch

.. image:: https://landscape.io/github/rolando/dask-elasticsearch/master/landscape.svg?style=flat
    :target: https://landscape.io/github/rolando/dask-elasticsearch/master
    :alt: Code Quality Status

.. image:: https://requires.io/github/rolando/dask-elasticsearch/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/rolando/dask-elasticsearch/requirements/?branch=master

Elasticsearch reader for Dask.

* Free software: MIT license
* Documentation: https://dask-elasticsearch.readthedocs.org.
* Python versions: 2.7, 3.4+

Features
--------

FIXME

Quickstart
----------

FIXME

Credits
-------

This package was created with Cookiecutter_ and the `rolando/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`rolando/cookiecutter-pypackage`: https://github.com/rolando/cookiecutter-pypackage
